summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/hierarchicalcodeblock.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /umbrello/umbrello/hierarchicalcodeblock.cpp
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/hierarchicalcodeblock.cpp')
-rw-r--r--umbrello/umbrello/hierarchicalcodeblock.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/umbrello/umbrello/hierarchicalcodeblock.cpp b/umbrello/umbrello/hierarchicalcodeblock.cpp
index eff7f463..7d31bf1d 100644
--- a/umbrello/umbrello/hierarchicalcodeblock.cpp
+++ b/umbrello/umbrello/hierarchicalcodeblock.cpp
@@ -114,7 +114,7 @@ bool HierarchicalCodeBlock::insertTextBlock(TextBlock * newBlock, TextBlock * ex
return false;
TQString tag = existingBlock->getTag();
// FIX: just do a quick check if the parent DOCUMENT has this.
// IF it does, then the lack of an index will force us into
// a search of any child hierarchical codeblocks we may have
// Its not efficient, but works. I don't think speed is a problem
@@ -123,7 +123,7 @@ bool HierarchicalCodeBlock::insertTextBlock(TextBlock * newBlock, TextBlock * ex
if(!getParentDocument()->findTextBlockByTag(tag, true))
return false;
- int index = m_textblockVector.findRef(existingBlock);
+ int index = m_textblockVector.tqfindRef(existingBlock);
if(index < 0)
{
// may be hiding in child hierarchical codeblock
@@ -149,7 +149,7 @@ bool HierarchicalCodeBlock::insertTextBlock(TextBlock * newBlock, TextBlock * ex
newBlock->setTag(new_tag);
}
- if(m_textBlockTagMap.contains(new_tag))
+ if(m_textBlockTagMap.tqcontains(new_tag))
return false; // return false, we already have some object with this tag in the list
else {
m_textBlockTagMap.insert(new_tag, newBlock);
@@ -202,7 +202,7 @@ void HierarchicalCodeBlock::setStartText ( const TQString &text ) {
}
/**
- * @return QString
+ * @return TQString
*/
TQString HierarchicalCodeBlock::getStartText ( ) {
return m_startText;
@@ -310,7 +310,7 @@ void HierarchicalCodeBlock::setAttributesFromObject (TextBlock * obj) {
/**
- * @return QString
+ * @return TQString
*/
TQString HierarchicalCodeBlock::toString ( ) {
@@ -365,7 +365,7 @@ TextBlock * HierarchicalCodeBlock::findCodeClassFieldTextBlockByTag ( const TQSt
if(cdoc)
return cdoc->findCodeClassFieldTextBlockByTag(tag);
else
- kError()<<" HierarchicalCodeBlock: findCodeClassFieldTextBlockByTag() finds NO parent document! Badly constructed textblock?!?"<<endl;
+ kError()<<" HierarchicalCodeBlock: findCodeClassFieldTextBlockByTag() finds NO tqparent document! Badly constructed textblock?!?"<<endl;
// if we get here, we failed.
return (TextBlock*) NULL;
@@ -114,7 +114,7 @@ bool HierarchicalCodeBlock::insertTextBlock(TextBlock * newBlock, TextBlock * ex
return false;
TQString tag = existingBlock->getTag();
- // FIX: just do a quick check if the parent DOCUMENT has this.
+ // FIX: just do a quick check if the tqparent DOCUMENT has this.
// IF it does, then the lack of an index will force us into
// a search of any child hierarchical codeblocks we may have